package com.ruoyi.hezhi.mapper;

import com.ruoyi.hezhi.domain.TbExamNotice;

import java.util.List;
import java.util.Map;

/**
 * 考试通知Mapper接口
 *
 * @author ruoyi
 * @date 2024-10-16
 */
public interface TbExamNoticeMapper
{
    /**
     * 查询考试通知
     *
     * @param examNoticeId 考试通知主键
     * @return 考试通知
     */
    public TbExamNotice selectTbExamNoticeByExamNoticeId(Long examNoticeId);

    /**
     * 查询考试通知列表
     *
     * @param tbExamNotice 考试通知
     * @return 考试通知集合
     */
    public List<TbExamNotice> selectTbExamNoticeList(TbExamNotice tbExamNotice);

    /**
     * 新增考试通知
     *
     * @param tbExamNotice 考试通知
     * @return 结果
     */
    public int insertTbExamNotice(TbExamNotice tbExamNotice);

    /**
     * 修改考试通知
     *
     * @param tbExamNotice 考试通知
     * @return 结果
     */
    public int updateTbExamNotice(TbExamNotice tbExamNotice);

    /**
     * 删除考试通知
     *
     * @param examNoticeId 考试通知主键
     * @return 结果
     */
    public int deleteTbExamNoticeByExamNoticeId(Long examNoticeId);

    /**
     * 批量删除考试通知
     *
     * @param examNoticeIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTbExamNoticeByExamNoticeIds(Long[] examNoticeIds);

    /**
     * 考试通知列表
     *
     * @param params 参数
     * @return 考试通知列表
     */
    public List<Map<String, Object>> getExamNoticeList(Map<String, Object> params);


    /**
     * 考试通知详情
     *
     * @param params 参数
     * @return 考试通知详情
     */
    public Map<String, Object> getExamNoticeInfo(Map<String, Object> params);
}
